@@ -124,7 +124,8 @@ test_that("star_database() define a a star database", {
           class = "dimension_table"
         )
       ),
-      rpd = list()
+      rpd = list(),
+      geo = list()
     ),
     class = "star_database"
   ))
@@ -240,7 +241,8 @@ test_that("star_database() define a a star database", {
           class = "dimension_table"
         )
       ),
-      rpd = list()
+      rpd = list(),
+      geo = list()
     ),
     class = "star_database"
   ))
@@ -374,7 +376,8 @@ test_that("snake_case() transform a a star database in snake case", {
           class = "dimension_table"
         )
       ),
-      rpd = list()
+      rpd = list(),
+      geo = list()
     ),
     class = "star_database"
   ))
@@ -1151,4 +1154,22 @@ test_that("get_dimension_names()", {
   }, {
     c("mrs_age", "mrs_cause", "when", "where", "who")
   })
+
+  expect_equal({
+    t <- ct |>
+      get_dimension_table("where")
+  }, {
+    structure(
+      list(
+        region = c("1", "1", "1", "1"),
+        state = c("CT",
+                  "CT", "MA", "MA"),
+        city = c("Bridgeport", "Hartford", "Boston",
+                 "Cambridge")
+      ),
+      row.names = c(NA,-4L),
+      class = c("tbl_df", "tbl",
+                "data.frame")
+    )
+  })
 })
